@@ -385,7 +385,7 @@ PCA_RDA_graphics <- function(complete.data.set, factor.names, sample.column,
   Table_RDA <- data.frame(0)
 
   #Get columns number of factors
-  colnumber <- which(names(complete.data.set)%in%factor.names)
+  colnumber <- as.numeric(which(names(complete.data.set)%in%factor.names))
   nbfactors <- length(factor.names)
 
 
@@ -396,12 +396,19 @@ PCA_RDA_graphics <- function(complete.data.set, factor.names, sample.column,
 
   }
 
-
   #Extract coords for individuals and variables
   nb_coords <- ncol(PCA.object$ind$coord)
 
-  data_ind_ACP <- cbind(data.frame(cbind(PCA.object$ind$coord[,c(1:nb_coords)])), complete.data.set[,c(colnumber)])
+  data_ind_ACP <- cbind(data.frame(cbind(PCA.object$ind$coord[,c(1:nb_coords)])), complete.data.set[,colnumber])
 
+  #force factor names
+  fc.names <- names(complete.data.set)[colnumber]
+
+  names.col.cds <- ncol(PCA.object$ind$coord[,c(1:nb_coords)]) + 1
+
+  names(data_ind_ACP)[names.col.cds:ncol(data_ind_ACP)] <- fc.names
+
+  ###
   nbnames.post.dims <- as.numeric(length(names(data_ind_ACP)))
 
   data_var_ACP <- cbind(data.frame(cbind(PCA.object$var$coord[,c(1:nb_coords)])))
